==================
HPGL web resources
==================

HPGL references
===============

* `http://local.wasp.uwa.edu.au/~pbourke/dataformats/hpgl/ <http://local.wasp.uwa.edu.au/~pbourke/dataformats/hpgl/>`_


Tools
=====

* `hp2xx <http://www.gnu.org/software/hp2xx/hp2xx.html>`_: an HPGL to *x* converter. Very handy for converting your HPGL files to other image formats. **hp2xx** in part of the GNU project, so in Linux simply use your package manager to install. (e.g., in Debian: ``sudo apt-get install hp2xx``). For other operating systems you will need to download and compile from source. 
   .. note::
         **hp2xx** is required for exporting and previewing in Chiplotle.
* `pstoedit <http://www.pstoedit.net/>`_: a Post Script to HPGL converter.
* `autotrace <http://autotrace.sourceforge.net/>`_: transform your bitmaps into vector graphics.
* `potrace <http://potrace.sourceforge.net/>`_: transform your bitmaps into vector graphics. Works a bit differently than ``autotrace``.
